<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ug">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>چىراي قۇلۇپى</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>دەلىللەندى</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>دەلىللەش مەغلۇپ بولدى، يەنە %n قېتىم سىنىيالايسىز</numerusform><numerusform>دەلىللەش مەغلۇپ بولدى، يەنە %n قېتىم سىنىيالايسىز</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>دەلىللەش مەغلۇپ بولدى، يەنە 1 قېتىم سىنىيالايسىز</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>چىراي قۇلۇپىڭىزنى دەلىللەڭ</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>چىرايدا قۇلۇپ ئېچىش قۇلۇپلىنىپ قالدى، پارولنى كىرگۈزۈڭ</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation>ئۈسكۈنىنى ئىشلەتكىلى بولمايدۇ!</translation>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>بارماق ئىزى ئارقىلىق دەلىللەڭ</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>دەلىللەندى</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>دەلىللەش مەغلۇپ بولدى، يەنە %n قېتىم سىنىيالايسىز</numerusform><numerusform>دەلىللەش مەغلۇپ بولدى، يەنە %n قېتىم سىنىيالايسىز</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>دەلىللەش مەغلۇپ بولدى، يەنە 1 قېتىم سىنىيالايسىز</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>بارماق ئىزىدا ئېچىش قۇلۇپلىنىپ قالدى، پارولنى كىرگۈزۈڭ</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>كۆز رەڭدار پەردىسى قۇلۇپى</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>دەلىللەندى</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>دەلىللەش مەغلۇپ بولدى، يەنە %n قېتىم سىنىيالايسىز</numerusform><numerusform>دەلىللەش مەغلۇپ بولدى، يەنە %n قېتىم سىنىيالايسىز</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>دەلىللەش مەغلۇپ بولدى، يەنە 1 قېتىم سىنىيالايسىز</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>كۆز رەڭدار پەردىڭىزنى دەلىللەڭ</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation> كۆز رەڭدار پەردىسىنى تونۇپ قۇلۇپنى ئېچىش قۇلۇپلىنىپ قالدى، پارولنى كىرگۈزۈڭ</translation>
    </message>
</context>
<context>
    <name>AuthPasskey</name>
    <message>
        <source>Please plug in the security key</source>
        <translation>بىخەتەرلىك ئاچقۇچىنى كىرگۈزۈڭ</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>دەلىللەندى</translation>
    </message>
    <message>
        <source>Verification failed</source>
        <translation>دەلىللەش مەغلۇپ بولدى</translation>
    </message>
    <message>
        <source>Identifying the security key</source>
        <translation>بىخەتەرلىك ئاچقۇچىنى تونۇۋاتىدۇ</translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>دەلىللەندى</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>دەلىللەش مەغلۇپ بولدى، يەنە %n قېتىم سىنىيالايسىز</numerusform><numerusform>دەلىللەش مەغلۇپ بولدى، يەنە %n قېتىم سىنىيالايسىز</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>دەلىللەش مەغلۇپ بولدى، يەنە 1 قېتىم سىنىيالايسىز</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>پارول خاتا</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>پارول</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>1 مىنۇتتىن كېيىن قايتا سىناڭ</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>%n مىنۇتتىن كېيىن قايتا سىناڭ</numerusform><numerusform>%n مىنۇتتىن كېيىن قايتا سىناڭ</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>قايتا پارول تەكشەش</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>پارول  قايتۇرۇش </translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>1 مىنۇتتىن كېيىن قايتا سىناڭ</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>%n مىنۇتتىن كېيىن قايتا سىناڭ</numerusform><numerusform>%n مىنۇتتىن كېيىن قايتا سىناڭ</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>قايتا پارول تەكشەش</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>پارول  قايتۇرۇش </translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>دەلىللەندى</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>دەلىللەش مەغلۇپ بولدى، يەنە %n قېتىم سىنىيالايسىز</numerusform><numerusform>دەلىللەش مەغلۇپ بولدى، يەنە %n قېتىم سىنىيالايسىز</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>دەلىللەش مەغلۇپ بولدى، يەنە 1 قېتىم سىنىيالايسىز</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>PIN خاتا</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>UKEY ئارقىلىق دەلىللەش كېرەك</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>UKEY بايقالدى، PINنى كىرگۈزۈڭ</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>%n مىنۇتتىن كېيىن قايتا سىناڭ</numerusform><numerusform>%n مىنۇتتىن كېيىن قايتا سىناڭ</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>1 مىنۇتتىن كېيىن قايتا سىناڭ</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>%n مىنۇتتىن كېيىن قايتا سىناڭ</numerusform><numerusform>%n مىنۇتتىن كېيىن قايتا سىناڭ</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>ھېسابات</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation><numerusform>پارولنىڭ ۋاقتى %n كۈندىن كېيىن توشىدۇ، پارولنى ۋاقتىدا ئۆزگەرتىڭ</numerusform><numerusform>پارولنىڭ ۋاقتى %n كۈندىن كېيىن توشىدۇ، پارولنى ۋاقتىدا ئۆزگەرتىڭ</numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>پارولنىڭ ۋاقتى ئۆتتى، ئۆزگەرتىڭ</translation>
    </message>
    <message>
        <source>Your password has expired. Please contact the administrator to change it</source>
        <translation>پارولىڭىزنىڭ ۋاقتى ئۆتۈپ كەتتى، باشقۇرغۇچى بىلەن ئالاقىلىشىپ پارول ئۆزگەرتىڭ</translation>
    </message>
    <message>
        <source>Terminal locked, please contact administrator</source>
        <translation>بۇ ئۈسكۈنە قۇلۇپلىنىپ قالدى، باشقۇرغۇچى بىلەن ئالاقىلىشىڭ</translation>
    </message>
</context>
<context>
    <name>DeepinAuthFramework</name>
    <message>
        <source>Wrong Password</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>ھېسابات نومۇرى خاتا</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>پارول خاتا</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>بىكار قىلىش</translation>
    </message>
    <message>
        <source>The reason of inhibit.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LighterGreeter</name>
    <message>
        <source>Standard Mode</source>
        <translation>ئۆلچەملىك ھالەت</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>ئېكران قۇلۇپى</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>ئېكران قۇلۇپلانمىدى</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>بارماق پارولىنى دەلىللەش ۋاقتى ئۆتۈپ كەتتى، پارول كىرگۈزۈڭ</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>ئېكراننى بارماق ئېزى ئارقىلىق ئېچىش مەغلۇپ بولدى</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>بىكار قىلىش</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>بۇ كومپيۇتېردا يەنە يۇقارقى ھېساباتلار ئوچۇق، تاقىۋەتسىڭىز سانلىق مەلۇماتلار يوقاپ كېتىشى مۇمكىن، راستلا تاقامسىز؟</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>بۇ كومپيۇتېردا يەنە يۇقارقى ھېساباتلار ئوچۇق، كومپيۇتېرنى قايتا قوزغاتسىڭىز سانلىق مەلۇماتلار يوقاپ كېتىدۇ، راستلا قايتا قوزغىتامسىز؟</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>يۇقىرى دەرىجىلىك قوغداشنى قوزغاتتىڭىز، Wayland ئەندىزىسىگە ئالماشتۇرغىلى بولمىدى، «بىخەتەرلىك مەركىزى»دىن يۇقىرى دەرىجىلىك قوغداشنى تاقىغاندىن كېيىن قايتا سىناڭ</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>تاقاش</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>قايتا قوزغىتىش</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>ئېسىپ قويۇش</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>ئۇخلاش ھالىتى</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>ئېكران قۇلۇپلاش</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>چېكىنىش</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>ئىشلەتكۈچى ئالماشتۇرۇش</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>سىستېما ئالماشتۇرۇش</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>يېڭىلاش ۋە تاقاش</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>يېڭىلاش ۋە قايتا قوزغىتىش</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>سىستېما نازارەتچىسىنى قوزغىتىش</translation>
    </message>
</context>
<context>
    <name>UdcpMFALoginWidget</name>
    <message>
        <source>发送验证码</source>
        <translation>دەلىللەش كودى يوللاش</translation>
    </message>
    <message>
        <source>请输入手机号</source>
        <translation>يانفون نومۇرىڭىزنى كىرگۈزۈڭ</translation>
    </message>
    <message>
        <source>请输入验证码</source>
        <translation>دەلىللەش كودىنى كىرگۈزۈڭ</translation>
    </message>
    <message>
        <source>获取验证码</source>
        <translation>دەلىللەش كودىغا ئېرىشىش</translation>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>Update</source>
        <translation>يېڭىلاش</translation>
    </message>
    <message>
        <source>Please plug in and then install updates.</source>
        <translation>توكقا چېتىپ ئاندىن يېڭىلاڭ</translation>
    </message>
</context>
<context>
    <name>UsersWithTheSameName</name>
    <message>
        <source>Return</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please select the account for login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Local Account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Domain Account</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>يۇقارقى پىروگراممىلار تاقاشقا توسقۇنلۇق قىلىۋاتىدۇ، مەجبۇرىي تاقىسىڭىز سانلىق مەلۇماتلىرىڭىز يوقاپ كېتىشى مۇمكىن.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>«بىكار قىلىش»نى چېكىپ بۇ پىروگراممىلارنى تاقىۋەتسىڭىز بولىدۇ.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>يۇقارقى پىروگراممىلار قايتا قوزغىتىشقا توسقۇنلۇق قىلىۋاتىدۇ، مەجبۇرىي قايتا قوزغاتسىڭىز سانلىق مەلۇماتلىرىڭىز يوقاپ كېتىشى مۇمكىن.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>يۇقارقى پىروگراممىلار ۋاقىتلىق تاقاشقا توسقۇنلۇق قىلىۋاتىدۇ، مەجبۇرىي ۋاقىتلىق تاقىسىڭىز سانلىق مەلۇماتلىرىڭىز يوقاپ كېتىشى مۇمكىن.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>يۇقارقى پىروگراممىلارئۇخلاش ھالىتىگە كىرىشكە توسقۇنلۇق قىلىۋاتىدۇ، مەجبۇرىي ئۇخلاش ھالىتىگە كىرسىڭىز سانلىق مەلۇماتلىرىڭىز يوقاپ كېتىشى مۇمكىن.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>يۇقارقى پىروگراممىلار چېكىنىشكە توسقۇنلۇق قىلىۋاتىدۇ، مەجبۇرىي قايتا كىرسىڭىز سانلىق مەلۇماتلىرىڭىز يوقاپ كېتىشى مۇمكىن.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>تاقاش</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>قايتا قوزغىتىش</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>ۋاقىتلىق تاقاش</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>ئۇخلاش ھالىتى</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>چېكىنىش</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>راستلا تاقامسىز؟</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>راستلا قايتا قوزغىتامسىز؟</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>راستلا چېكىنەمسىز؟</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>يېڭىلاش ۋە تاقاش</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>يېڭىلاش ۋە قايتا قوزغىتىش</translation>
    </message>
    <message>
        <source>Closing the programs and shutting down, please wait...</source>
        <translation>يۇقىرىقى پىروگراممىلارنى تاقاپ ئۆچۈۋاتىدۇ، سەل ساقلاڭ...</translation>
    </message>
    <message>
        <source>Closing the programs and rebooting, please wait...</source>
        <translation>يۇقىرىقى پىروگراممىلارنى تاقاپ قايتا قوزغىلىۋاتىدۇ، سەل ساقلاڭ...</translation>
    </message>
    <message>
        <source>Closing the programs and logging out, please wait...</source>
        <translation>يۇقىرىقى پىروگراممىلارنى تاقاپ چېكىنىۋاتىدۇ، سەل ساقلاڭ...</translation>
    </message>
</context>
<context>
    <name>dss::module::AssistLoginWidget</name>
    <message>
        <source>Automatic login</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>ئاچ</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>تاقا</translation>
    </message>
</context>
</TS>